security: Renaming EcdsaKeyParams to EcKeyParams

Change-Id: If27faf095474f5be3f8f454925b389b97bf4425d
Refs: #3135
diff --git a/src/security/key-params.hpp b/src/security/key-params.hpp
index 8f28a3e..ee46c71 100644
--- a/src/security/key-params.hpp
+++ b/src/security/key-params.hpp
@@ -1,6 +1,6 @@
 /* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /**
- * Copyright (c) 2013-2016 Regents of the University of California.
+ * Copyright (c) 2013-2017 Regents of the University of California.
  *
  * This file is part of ndn-cxx library (NDN C++ library with eXperimental eXtensions).
  *
@@ -122,8 +122,8 @@
   getDefaultSize();
 };
 
-/// @brief EcdsaKeyParamInfo is used to initialize a SimplePublicKeyParams template for ECDSA key.
-class EcdsaKeyParamsInfo
+/// @brief EcKeyParamInfo is used to initialize a SimplePublicKeyParams template for elliptic curve key.
+class EcKeyParamsInfo
 {
 public:
   static KeyType
@@ -199,9 +199,8 @@
 /// @brief RsaKeyParams carries parameters for RSA key.
 typedef SimplePublicKeyParams<RsaKeyParamsInfo> RsaKeyParams;
 
-/// @brief EcdsaKeyParams carries parameters for ECDSA key.
-typedef SimplePublicKeyParams<EcdsaKeyParamsInfo> EcdsaKeyParams;
-
+/// @brief EcKeyParams carries parameters for EC key.
+typedef SimplePublicKeyParams<EcKeyParamsInfo> EcKeyParams;
 
 /// @brief AesKeyParamsInfo is used to initialize a SimpleSymmetricKeyParams template for AES key.
 class AesKeyParamsInfo
@@ -225,7 +224,6 @@
   getDefaultSize();
 };
 
-
 /// @brief SimpleSymmetricKeyParams is a template for symmetric keys with only one parameter: size.
 template<typename KeyParamsInfo>
 class SimpleSymmetricKeyParams : public KeyParams